# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import serializers
from rest_framework.exceptions import ValidationError

__all__ = [
    "ImportSerializer",
    "ExportSerializer",
    "SendExportSerializer",
]


class _ImportExportSerializerMixin(serializers.Serializer):
    def get_user_id(self):
        return self.context['request'].user.id

    def get_parameters(self):
        parameters = self.validated_data
        parameters['user_id'] = self.get_user_id()
        return parameters

    def create(self, validated_data):
        return NotImplemented

    def update(self, instance, validated_data):
        return NotImplemented


class ImportSerializer(_ImportExportSerializerMixin):
    filename = serializers.FileField()

    class Meta:
        fields = ('filename',)


class ExportSerializer(_ImportExportSerializerMixin):
    file_name = serializers.CharField(required=False)

    class Meta:
        fields = ('file_name',)

    def get_file_name(self, value):
        """Hook this method to provide ad default `file_name`"""
        if not value:
            raise ValidationError({"file_name": _('This field is required.')})
        return value

    def get_parameters(self):
        parameters = super().get_parameters()
        parameters['file_name'] = self.get_file_name(parameters.get('file_name'))
        return parameters


class SendExportSerializer(ExportSerializer):
    email = serializers.CharField(required=True)
    subject = serializers.CharField(max_length=255, required=False)

    class Meta:
        fields = ('file_name', 'email', 'subject',)

    def get_subject(self, value):
        """Hook this method to provide ad default `subject`"""
        if not value:
            raise ValidationError({"subject": _('This field is required.')})
        return value

    def get_parameters(self):
        parameters = super().get_parameters()
        parameters['subject'] = self.get_subject(parameters.get('subject'))
        return parameters
